@@ -16,6 +16,7 @@ from suite_py.commands import create_qa
 from suite_py.commands import delete_qa
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.config import Config
+from suite_py.__version__ import __version__
 
 
 config = Config().load()
@@ -45,6 +46,7 @@ def confirm_cwd():
 @click.pass_context
 def main(ctx, project, timeout):
     Package('suite_py', verbose=True).smartupgrade()
+    print("suite-py v{}".format(__version__))
     project_name = os.path.basename(project)
     ctx.ensure_object(dict)
     ctx.obj['project'] = project_name
@@ -73,7 +75,8 @@ def cli_create_branch(ctx, card):
 @click.argument("action", type=click.Choice(("lock", "l", "unlock", "u")))
 @click.pass_context
 def cli_lock_project(ctx, action):
-    lock_project.entrypoint(ctx.obj['project'], action, ctx.obj['captainhook_timeout'])
+    lock_project.entrypoint(
+        ctx.obj['project'], action, ctx.obj['captainhook_timeout'])
 
 
 @main.command("open-pr", help="Apre una PR su GitHub")
