@@ -1,40 +1,42 @@
-from __future__ import print_function, unicode_literals
-from ..lib.handler.youtrack_handler import YoutrackHandler
-from ..lib.handler.github_handler import GithubHandler
-from ..lib.handler import git_handler as git
-from ..lib.config import Config
-from ..lib.logger import Logger
-from ..lib.handler import prompt_utils
-
+# -*- coding: utf-8 -*-
 import re
 import sys
 
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
+from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler import git_handler as git
+from suite_py.lib.config import Config
+from suite_py.lib.logger import Logger
+from suite_py.lib.handler import prompt_utils
+
+
 youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
 config = Config().load()
 
 
-def entrypoint(args):
-    git.is_dirty(args.project)
+def entrypoint(project, card):
+    git.is_dirty(project)
 
     try:
-        if args.card:
-            issue = youtrack.get_issue(args.card)
+        if card:
+            issue = youtrack.get_issue(card)
         else:
             issue = youtrack.get_issue(ask_card())
     except:
         logger.error("Si e' verificato un problema recuperando la issue da youtrack. Controlla che il numero della issue e' corretto")
         sys.exit(-1)
 
-    checkout_branch(args.project, issue)
+    checkout_branch(project, issue)
 
     youtrack.assign_to(issue["id"], "me")
 
     youtrack.update_state(issue["id"], config["youtrack"]["picked_state"])
 
 def ask_card():
-    return prompt_utils.ask_questions_input('Inserisci il numero della issue youtrack: ', "PRIMA-XXX")
+    return prompt_utils.ask_questions_input(
+        'Inserisci il numero della issue youtrack:', config['user']['default_slug'])
 
 def checkout_branch(project, issue):
     branch_name = prompt_utils.ask_questions_input("Inserisci nome del branch: ", re.sub(
