@@ -1,17 +1,19 @@
-from __future__ import print_function, unicode_literals
-from halo import Halo
-from ..lib.handler.youtrack_handler import YoutrackHandler
-from ..lib.handler.github_handler import GithubHandler
-from ..lib.handler import git_handler as git
-from ..lib.handler import drone_handler as drone
-from ..lib.handler import prompt_utils
-from ..lib.logger import Logger
-from ..lib.qainit import get_qa_projects, qainit_deploy
-from ..lib.config import Config
-
+# -*- coding: utf-8 -*-
+import json
 import subprocess
 import sys
-import json
+
+from halo import Halo
+
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
+from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler import git_handler as git
+from suite_py.lib.handler import drone_handler as drone
+from suite_py.lib.handler import prompt_utils
+from suite_py.lib.logger import Logger
+from suite_py.lib.qainit import get_qa_projects, qainit_deploy
+from suite_py.lib.config import Config
+
 
 youtrack = YoutrackHandler()
 github = GithubHandler()
@@ -19,10 +21,10 @@ logger = Logger()
 config = Config().load()
 
 
-def entrypoint(args):
+def entrypoint(project):
     qa_projects = get_qa_projects()
-    if args.project not in qa_projects:
-        logger.error("Il progetto {} non fa parte degli ambienti di QA, niente da fare".format(args.project))
+    if project not in qa_projects:
+        logger.error("Il progetto {} non fa parte degli ambienti di QA, niente da fare".format(project))
         sys.exit(0)
 
     with Halo(text='Updating prima-twig...', spinner='dots', color='magenta'):
@@ -40,11 +42,11 @@ def entrypoint(args):
         if prompt_utils.ask_confirm("Ci sono altri progetti da aggiungere al QA che fanno riferimento alla card {}?".format(youtrack_id), default=False):
             twig_arg = multi_repo_qa(youtrack_id, qa_projects)
         else:
-            twig_arg = mono_repo_qa(args.project, branch_name)
+            twig_arg = mono_repo_qa(project, branch_name)
     else:
         logger.warning("Non sono riuscito a trovare una issue YouTrack collegata al branch, non e' possibile collegare automaticamente altri progetti a questo QA")
         logger.warning("Se vuoi creare il QA con diversi branch su diversi progetti per favore interrompi il comando ed utilizza twig")
-        twig_arg = mono_repo_qa(args.project, branch_name)
+        twig_arg = mono_repo_qa(project, branch_name)
 
     qainit_deploy(twig_arg)
 
