@@ -1,16 +1,19 @@
-from __future__ import print_function, unicode_literals
-from ..lib.handler.youtrack_handler import YoutrackHandler
-from ..lib.handler.github_handler import GithubHandler
-from ..lib.handler.slack_handler import SlackHandler
-from ..lib.handler import prompt_utils
-from ..lib.handler import git_handler as git
-from ..lib.handler import drone_handler as drone
-from ..lib.logger import Logger
-from ..lib.config import Config
-from halo import Halo
+# -*- coding: utf-8 -*-
 import sys
+
+from halo import Halo
 import semver
 
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
+from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.slack_handler import SlackHandler
+from suite_py.lib.handler import prompt_utils
+from suite_py.lib.handler import git_handler as git
+from suite_py.lib.handler import drone_handler as drone
+from suite_py.lib.logger import Logger
+from suite_py.lib.config import Config
+
+
 youtrack = YoutrackHandler()
 github = GithubHandler()
 config = Config().load()
@@ -18,15 +21,15 @@ logger = Logger()
 slack = SlackHandler()
 
 
-def entrypoint(args):
+def entrypoint(project):
     if prompt_utils.ask_confirm("Sono presenti migration?", default=False):
         logger.error(
             "Impossibile continuare con il deploy a causa di migration presenti. Chiedi ai devops di effettuare il deploy.")
         sys.exit(-1)
 
-    git.is_dirty(args.project)
-    git.fetch(args.project)
-    repo = github.get_repo(args.project)
+    git.is_dirty(project)
+    git.fetch(project)
+    repo = github.get_repo(project)
 
     latest_release = get_release(repo)
 
@@ -68,16 +71,17 @@ def entrypoint(args):
         try:
             deployed_cards_link.append(youtrack.get_link(issue_id))
             youtrack.comment(
-                issue_id, "Deploy in produzione effettuato con la release {}".format(new_version))
+                issue_id, "Deploy in produzione di {} effettuato con la release {}".format(args.project, new_version))
             youtrack.update_state(
                 issue_id, release_state
             )
         except:
-            logger.warning("Si è verificato un errore durante lo spostamento della card {} in {}".format(
-                issue_id, release_state))
+            logger.warning(
+                "Si è verificato un errore durante lo spostamento della card {} in {}".format(
+                issue_id, release_state)
+            )
 
-    create_release(repo, new_version, message,
-                   args.project, deployed_cards_link)
+    create_release(repo, new_version, message, project, deployed_cards_link)
 
 
 def get_release(repo):
