@@ -31,7 +31,6 @@ def entrypoint(project, timeout):
     branch_name = pr.head.ref
     youtrack_id = youtrack.get_card_from_name(branch_name)
 
-
     check_migrations_merge(pr)
 
     logger.info("Eseguo il merge...")
@@ -86,13 +85,13 @@ def select_pr(project):
         prs = list(filter(lambda pr: pr.mergeable and pr.mergeable_state ==
                           "clean", github.get_list_pr(project)))
 
-    if prs.totalCount > 0:
+    if hasattr(prs, 'totalCount') and prs.totalCount > 0:
         choices = [{"name": "{} {}".format(
             i.number, i.title), "value": i} for i in prs]
         return prompt_utils.ask_choices('Seleziona PR: ', choices)
     else:
-        logger.warning(
-            "Non esistono pull request pronte per il merge, per favore controlla su https://github.com/primait/{}/pulls".format(project))
+        logger.error(
+            "Non esistono pull request pronte per il merge o potresti non avere i permessi, per favore controlla su https://github.com/primait/{}/pulls".format(project))
         sys.exit(-1)
 
 
