@@ -7,6 +7,7 @@ from suite_py.lib.logger import Logger
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
+from suite_py.commands import ask_review
 
 
 youtrack = YoutrackHandler()
@@ -71,7 +72,8 @@ def create_pr(repo, branch_name, id_card=None):
 
     try:
         pr = github.create_pr(repo, branch_name, title, body)
-        logger.info("Pull request numero {} creata!".format(pr.number))
+        logger.info("Pull request numero {} creata! {}".format(
+            pr.number, pr.html_url))
     except GithubException as e:
         logger.error('Errore durante la richiesta a GitHub: ')
         logger.error(e.data["errors"][0])
@@ -82,6 +84,9 @@ def create_pr(repo, branch_name, id_card=None):
         logger.info(
             "Inserito link della pull request nella card {}".format(id_card))
 
+    if prompt_utils.ask_confirm("Vuoi inserire i reviewers?"):
+        ask_review.entrypoint(repo, config['user']['captainhook_timeout'])
+
 
 def ask_for_description(pr_body=""):
     input("Inserisci la description della pull request. Premendo invio si aprira l'editor di default")
