@@ -9,8 +9,8 @@ from suite_py.lib.logger import Logger
 
 logger = Logger()
 
-cloudformation = boto3.client('cloudformation')
-cloudfront = boto3.client('cloudfront')
+cloudformation = boto3.client('cloudformation', region_name='eu-west-1')
+cloudfront = boto3.client('cloudfront', region_name='eu-west-1')
 
 
 def update_stack(stack_name, version):
