@@ -1,8 +1,12 @@
-from ..tokens import Tokens
+# -*- encoding: utf-8 -*-
 from distutils.version import StrictVersion
+import time
+
 from halo import Halo
 import requests
-import time
+
+from suite_py.lib.tokens import Tokens
+
 
 tokens = Tokens()
 baseurl = "https://drone-1.prima.it"
