@@ -1,13 +1,15 @@
-from __future__ import print_function, unicode_literals
-from subprocess import CalledProcessError
-from ..logger import Logger
-from ..config import Config
+# -*- encoding: utf-8 -*-
 import os
-import subprocess
-import sys
 import re
-import semver
+import subprocess
+from subprocess import CalledProcessError
+import sys
+
 from halo import Halo
+import semver
+
+from suite_py.lib.logger import Logger
+from suite_py.lib.config import Config
 
 logger = Logger()
 config = Config().load()
