@@ -1,9 +1,12 @@
-from __future__ import print_function, unicode_literals
-from ..tokens import Tokens
-from ..singleton import Singleton
+# -*- encoding: utf-8 -*-
+import os
+
 from github import Github
 from github.GithubException import GithubException, UnknownObjectException
-import os
+
+from suite_py.lib.tokens import Tokens
+from suite_py.lib.singleton import Singleton
+
 
 tokens = Tokens()
 
