@@ -1,14 +1,15 @@
-from __future__ import print_function, unicode_literals
-from ..tokens import Tokens
-from ..config import Config
-from ..singleton import Singleton
-from youtrack.connection import Connection
-from youtrack.youtrack import YouTrackException
-from PyInquirer import prompt
-
+# -*- encoding: utf-8 -*-
 import os
 import re
 
+from PyInquirer import prompt
+from youtrack.connection import Connection
+from youtrack.youtrack import YouTrackException
+
+from suite_py.lib.tokens import Tokens
+from suite_py.lib.config import Config
+from suite_py.lib.singleton import Singleton
+
 tokens = Tokens()
 config = Config().load()
 
